Welcome to ndonnx's documentation!
======================================

ndonnx is an ONNX-backed Python array library that implements the `Array API standard <https://data-apis.org/array-api/latest/>`_.

.. toctree::
   :maxdepth: 1
   :caption: Guides

   Getting Started <intros/gettingstarted>
   Model Conversion <intros/modelconversion>
   Interoperating with Spox <spox/spoxintegration>

.. toctree::
   :maxdepth: 2
   :caption: API Documentation

   API Reference <api/modules>
   Data Types <datatypes/datatypes>

.. toctree::
   :maxdepth: 1
   :caption: Advanced Use Cases

   Experimental Features <experimental/experimental>
   Inference Utilities <inference/inference>

.. toctree::
    :maxdepth: 1
    :caption: Other

    Motivation <motivation/motivation>
    Changelog <changelog>
